"""Plugin for py.test that associates tests with github issues using a marker."""

__version__ = "0.2.0"
__author__ = "James Laska"
__author_email__ = "<jlaska@redhat.com>"
